@@ -3,11 +3,10 @@ from rpcclient.clients.darwin.subsystems.reports import Reports
 from rpcclient.clients.macos.subsystems.apple_script import AppleScript
 from rpcclient.core.subsystems.decorator import subsystem
 
-CRASH_REPORTS_DIR = 'Library/Logs/DiagnosticReports'
+CRASH_REPORTS_DIR = "Library/Logs/DiagnosticReports"
 
 
 class MacosClient(DarwinClient):
-
     @subsystem
     def reports(self) -> Reports:
         return Reports(self, CRASH_REPORTS_DIR)
@@ -18,10 +17,10 @@ class MacosClient(DarwinClient):
 
     @property
     def roots(self) -> list[str]:
-        """ get a list of all accessible darwin roots when used for lookup of files/preferences/... """
+        """get a list of all accessible darwin roots when used for lookup of files/preferences/..."""
 
         result = super().roots
-        for username in self.fs.scandir('/Users'):
+        for username in self.fs.scandir("/Users"):
             if not username.is_dir() or not self.fs.accessible(username.path):
                 continue
             result.append(username.path)
