@@ -8,18 +8,27 @@ import threading
 import typing
 from collections import namedtuple
 from enum import Enum, auto
-from functools import wraps
+from functools import cached_property, wraps
 from pathlib import Path
 from select import select
 from typing import Any, Optional
 
-from cached_property import cached_property
 from xonsh.built_ins import XSH
 from xonsh.main import main as xonsh_main
 
 from rpcclient.core.capture_fd import CaptureFD
-from rpcclient.core.structs.consts import EAGAIN, ECONNREFUSED, EEXIST, EISDIR, ENOENT, ENOTDIR, ENOTEMPTY, EPERM, \
-    EPIPE, RTLD_NEXT
+from rpcclient.core.structs.consts import (
+    EAGAIN,
+    ECONNREFUSED,
+    EEXIST,
+    EISDIR,
+    ENOENT,
+    ENOTDIR,
+    ENOTEMPTY,
+    EPERM,
+    EPIPE,
+    RTLD_NEXT,
+)
 from rpcclient.core.subsystems.decorator import subsystem
 from rpcclient.core.subsystems.fs import Fs
 from rpcclient.core.subsystems.lief import Lief
@@ -29,9 +38,21 @@ from rpcclient.core.subsystems.sysctl import Sysctl
 from rpcclient.core.symbol import Symbol
 from rpcclient.core.symbols_jar import SymbolsJar
 from rpcclient.event_notifier import EventNotifier
-from rpcclient.exceptions import ArgumentError, BadReturnValueError, RpcBrokenPipeError, RpcConnectionRefusedError, \
-    RpcFileExistsError, RpcFileNotFoundError, RpcIsADirectoryError, RpcNotADirectoryError, RpcNotEmptyError, \
-    RpcPermissionError, RpcResourceTemporarilyUnavailableError, ServerResponseError, SpawnError
+from rpcclient.exceptions import (
+    ArgumentError,
+    BadReturnValueError,
+    RpcBrokenPipeError,
+    RpcConnectionRefusedError,
+    RpcFileExistsError,
+    RpcFileNotFoundError,
+    RpcIsADirectoryError,
+    RpcNotADirectoryError,
+    RpcNotEmptyError,
+    RpcPermissionError,
+    RpcResourceTemporarilyUnavailableError,
+    ServerResponseError,
+    SpawnError,
+)
 from rpcclient.protocol.rpc_bridge import RpcBridge
 from rpcclient.protos.rpc_api_pb2 import Argument, MsgId
 from rpcclient.protos.rpc_pb2 import ProtocolConstants
@@ -43,16 +64,16 @@ try:
 
     tty_support = True
 except ImportError:
-    logging.warning('termios not available on your system. some functionality may not work as expected')
+    logging.warning("termios not available on your system. some functionality may not work as expected")
 
-io_or_str = typing.TypeVar('io_or_str', typing.IO, str)
+io_or_str = typing.TypeVar("io_or_str", typing.IO, str)
 
-SpawnResult = namedtuple('SpawnResult', 'error pid stdout')
+SpawnResult = namedtuple("SpawnResult", "error pid stdout")
 
-INVALID_PID = 0xffffffff
+INVALID_PID = 0xFFFFFFFF
 CHUNK_SIZE = 1024
 
-USAGE = '''
+USAGE = """
 Welcome to the rpcclient interactive shell! You interactive shell for controlling the remote rpcserver.
 Feel free to use the following globals:
 
@@ -61,7 +82,7 @@ Feel free to use the following globals:
 
 Have a nice flight ✈️!
 Starting an IPython shell... 🐍
-'''
+"""
 
 
 @dataclasses.dataclass
@@ -115,21 +136,22 @@ def null_pointer_guard(func: typing.Callable) -> typing.Callable:
     @wraps(func)
     def wrapper(self: typing.Any, address: int, *args: typing.Any, **kwargs: typing.Any) -> typing.Any:
         if address == 0:
-            raise ArgumentError('Unable dereference null pointer.')
+            raise ArgumentError("Unable dereference null pointer.")
         return func(self, address, *args, **kwargs)
 
     return wrapper
 
 
 class CoreClient:
-    """ Main client interface to access the remote rpcserver """
-    DEFAULT_ARGV = ['/bin/sh']
-    DEFAULT_ENVP = []
+    """Main client interface to access the remote rpcserver"""
+
+    DEFAULT_ARGV: typing.ClassVar = ["/bin/sh"]
+    DEFAULT_ENVP: typing.ClassVar = []
 
     def __init__(self, bridge: RpcBridge, dlsym_global_handle=RTLD_NEXT):
         self._bridge = bridge
         self._old_settings = None
-        self._endianness = '<'
+        self._endianness = "<"
         self._dlsym_global_handle = dlsym_global_handle
         self._protocol_lock = threading.Lock()
         self._logger = logging.getLogger(self.__module__)
@@ -157,30 +179,30 @@ class CoreClient:
         return Sysctl(self)
 
     def info(self):
-        """ print information about the current target """
+        """print information about the current target"""
         uname = self.uname
-        print('sysname:', uname.sysname)
-        print('nodename:', uname.nodename)
-        print('release:', uname.release)
-        print('version:', uname.version)
-        print('machine:', uname.machine)
-        print(f'uid: {self.symbols.getuid():d}')
-        print(f'gid: {self.symbols.getgid():d}')
-        print(f'pid: {self.pid:d}')
-        print(f'ppid: {self.symbols.getppid():d}')
-        print(f'progname: {self.progname}')
+        print("sysname:", uname.sysname)
+        print("nodename:", uname.nodename)
+        print("release:", uname.release)
+        print("version:", uname.version)
+        print("machine:", uname.machine)
+        print(f"uid: {self.symbols.getuid():d}")
+        print(f"gid: {self.symbols.getgid():d}")
+        print(f"pid: {self.pid:d}")
+        print(f"ppid: {self.symbols.getppid():d}")
+        print(f"progname: {self.progname}")
 
     @cached_property
     def progname(self) -> str:
-        """ get the program name from remote """
+        """get the program name from remote"""
         # bugfix https://github.com/doronz88/rpc-project/issues/405
         # Default Linux libraries don't expose `getprogname()`, so instead we use the `__progname` global symbol.
         # Tested on both macOS and Ubuntu.
-        return self.symbols['__progname'][0].peek_str()
+        return self.symbols["__progname"][0].peek_str()
 
     @cached_property
     def uname(self):
-        """ get the utsname struct from remote """
+        """get the utsname struct from remote"""
         raise NotImplementedError()
 
     @property
@@ -209,21 +231,28 @@ class CoreClient:
             raise
 
     def dlopen(self, filename: str, mode: int) -> Symbol:
-        """ call dlopen() at remote and return its handle. see the man page for more details. """
+        """call dlopen() at remote and return its handle. see the man page for more details."""
         return self.symbol(self.rpc_call(MsgId.REQ_DLOPEN, filename=filename, mode=mode).handle)
 
     def dlclose(self, lib: int) -> int:
-        """ call dlclose() at remote and return its handle. see the man page for more details. """
+        """call dlclose() at remote and return its handle. see the man page for more details."""
         return self.rpc_call(MsgId.REQ_DLCLOSE, handle=ctypes.c_uint64(lib).value).res
 
     def dlsym(self, lib: int, symbol_name: str) -> int:
-        """ call dlsym() at remote and return its handle. see the man page for more details. """
+        """call dlsym() at remote and return its handle. see the man page for more details."""
         return self.rpc_call(MsgId.REQ_DLSYM, handle=ctypes.c_uint64(lib).value, symbol_name=symbol_name).ptr
 
     @null_pointer_guard
-    def call(self, address: int, argv: list[int] = None, return_float64=False, return_float32=False,
-             return_raw=False, va_list_index: int = 0xffff) -> typing.Union[float, Symbol, Any]:
-        """ call a remote function and retrieve its return value as a Symbol object """
+    def call(
+        self,
+        address: int,
+        argv: Optional[list[int]] = None,
+        return_float64=False,
+        return_float32=False,
+        return_raw=False,
+        va_list_index: int = 0xFFFF,
+    ) -> typing.Union[float, Symbol, Any]:
+        """call a remote function and retrieve its return value as a Symbol object"""
         args = []
         for arg in argv:
             if isinstance(arg, float):
@@ -240,7 +269,7 @@ class CoreClient:
                 raise ArgumentError()
 
         ret = self.rpc_call(MsgId.REQ_CALL, address=address, va_list_index=va_list_index, argv=args)
-        if ret.HasField('arm_registers'):
+        if ret.HasField("arm_registers"):
             d0 = ret.arm_registers.d0
             if return_float32:
                 return ctypes.c_float(d0).value
@@ -253,53 +282,81 @@ class CoreClient:
 
     @null_pointer_guard
     def peek(self, address: int, size: int) -> bytes:
-        """ peek data at the given address """
+        """peek data at the given address"""
         try:
             return self.rpc_call(MsgId.REQ_PEEK, address=address, size=size).data
-        except ServerResponseError:
-            raise ArgumentError()
+        except ServerResponseError as e:
+            raise ArgumentError() from e
 
     @null_pointer_guard
     def poke(self, address: int, data: bytes):
-        """ poke data at a given address """
+        """poke data at a given address"""
         try:
             return self.rpc_call(MsgId.REQ_POKE, address=address, data=data)
-        except ServerResponseError:
-            raise ArgumentError()
+        except ServerResponseError as e:
+            raise ArgumentError() from e
 
     def get_dummy_block(self) -> Symbol:
-        """ get an address for a stub block containing nothing """
+        """get an address for a stub block containing nothing"""
         return self.symbol(self.rpc_call(MsgId.REQ_DUMMY_BLOCK).address)
 
     def listdir(self, path: str):
-        """ get an address for a stub block containing nothing """
+        """get an address for a stub block containing nothing"""
         entries = []
         try:
             ret = self.rpc_call(MsgId.REQ_LIST_DIR, path=path)
         except ServerResponseError:
-            self.raise_errno_exception(f'failed to listdir: {path}')
+            self.raise_errno_exception(f"failed to listdir: {path}")
 
         for entry in ret.dir_entries:
             lstat = ProtocolDitentStat(
-                errno=entry.lstat.errno1, st_blocks=entry.lstat.st_blocks, st_blksize=entry.lstat.st_blksize,
-                st_atime=entry.lstat.st_atime1, st_ctime=entry.lstat.st_ctime1, st_mtime=entry.lstat.st_mtime1,
-                st_nlink=entry.lstat.st_nlink, st_mode=entry.lstat.st_mode, st_rdev=entry.lstat.st_rdev,
-                st_size=entry.lstat.st_size, st_dev=entry.lstat.st_dev, st_gid=entry.lstat.st_gid,
-                st_ino=entry.lstat.st_ino, st_uid=entry.lstat.st_uid)
+                errno=entry.lstat.errno1,
+                st_blocks=entry.lstat.st_blocks,
+                st_blksize=entry.lstat.st_blksize,
+                st_atime=entry.lstat.st_atime1,
+                st_ctime=entry.lstat.st_ctime1,
+                st_mtime=entry.lstat.st_mtime1,
+                st_nlink=entry.lstat.st_nlink,
+                st_mode=entry.lstat.st_mode,
+                st_rdev=entry.lstat.st_rdev,
+                st_size=entry.lstat.st_size,
+                st_dev=entry.lstat.st_dev,
+                st_gid=entry.lstat.st_gid,
+                st_ino=entry.lstat.st_ino,
+                st_uid=entry.lstat.st_uid,
+            )
             stat = ProtocolDitentStat(
-                errno=entry.stat.errno1, st_blocks=entry.stat.st_blocks, st_blksize=entry.stat.st_blksize,
-                st_atime=entry.stat.st_atime1, st_ctime=entry.stat.st_ctime1, st_mtime=entry.stat.st_mtime1,
-                st_nlink=entry.stat.st_nlink, st_mode=entry.stat.st_mode, st_rdev=entry.stat.st_rdev,
-                st_size=entry.stat.st_size, st_dev=entry.stat.st_dev, st_gid=entry.stat.st_gid,
-                st_ino=entry.stat.st_ino, st_uid=entry.stat.st_uid)
+                errno=entry.stat.errno1,
+                st_blocks=entry.stat.st_blocks,
+                st_blksize=entry.stat.st_blksize,
+                st_atime=entry.stat.st_atime1,
+                st_ctime=entry.stat.st_ctime1,
+                st_mtime=entry.stat.st_mtime1,
+                st_nlink=entry.stat.st_nlink,
+                st_mode=entry.stat.st_mode,
+                st_rdev=entry.stat.st_rdev,
+                st_size=entry.stat.st_size,
+                st_dev=entry.stat.st_dev,
+                st_gid=entry.stat.st_gid,
+                st_ino=entry.stat.st_ino,
+                st_uid=entry.stat.st_uid,
+            )
             entries.append(
-                ProtocolDirent(d_inode=entry.lstat.st_ino, d_type=entry.d_type, d_name=entry.d_name,
-                               lstat=lstat,
-                               stat=stat))
+                ProtocolDirent(
+                    d_inode=entry.lstat.st_ino, d_type=entry.d_type, d_name=entry.d_name, lstat=lstat, stat=stat
+                )
+            )
         return entries
 
-    def spawn(self, argv: list[str] = None, envp: list[str] = None, stdin: io_or_str = sys.stdin,
-              stdout=sys.stdout, raw_tty=False, background=False) -> SpawnResult:
+    def spawn(
+        self,
+        argv: Optional[list[str]] = None,
+        envp: Optional[list[str]] = None,
+        stdin: io_or_str = sys.stdin,
+        stdout=sys.stdout,
+        raw_tty=False,
+        background=False,
+    ) -> SpawnResult:
         """
         spawn a new process and forward its stdin, stdout & stderr
 
@@ -318,13 +375,8 @@ class CoreClient:
             envp = self.DEFAULT_ENVP
 
         with self._protocol_lock:
-            try:
-                pid = self._execute(argv, envp, background=background)
-            except SpawnError:
-                # depends on where the error occurred, the socket might be closed
-                raise
-
-            self._logger.info(f'shell process started as pid: {pid}')
+            pid = self._execute(argv, envp, background=background)
+            self._logger.info(f"shell process started as pid: {pid}")
 
             if background:
                 return SpawnResult(error=None, pid=pid, stdout=None)
@@ -333,7 +385,7 @@ class CoreClient:
                 self._prepare_terminal()
             try:
                 error = self.enter_pty_mode(stdin, stdout)
-            except Exception:  # noqa: E722
+            except Exception:
                 # this is important to really catch every exception here, even exceptions not inheriting from Exception
                 # so the controlling terminal will remain working with its previous settings
                 if raw_tty:
@@ -343,7 +395,7 @@ class CoreClient:
         return SpawnResult(error=error, pid=pid, stdout=stdout)
 
     def symbol(self, symbol: int):
-        """ at a symbol object from a given address """
+        """at a symbol object from a given address"""
         return Symbol.create(symbol, self)
 
     @property
@@ -356,11 +408,11 @@ class CoreClient:
 
     @property
     def last_error(self):
-        """ get info about the last occurred error """
+        """get info about the last occurred error"""
         if not self.errno:
-            return ''
+            return ""
         err_str = self.symbols.strerror(self.errno).peek_str()
-        return f'[{self.errno}] {err_str}'
+        return f"[{self.errno}] {err_str}"
 
     @property
     def environ(self) -> list[str]:
@@ -373,11 +425,11 @@ class CoreClient:
         return result
 
     def setenv(self, name: str, value: str):
-        """ set process environment variable """
+        """set process environment variable"""
         self.symbols.setenv(name, value)
 
     def getenv(self, name: str) -> typing.Optional[str]:
-        """ get process environment variable """
+        """get process environment variable"""
         value = self.symbols.getenv(name)
         if not value:
             return None
@@ -390,7 +442,7 @@ class CoreClient:
     @contextlib.contextmanager
     def safe_calloc(self, size: int):
         with self.safe_malloc(size) as x:
-            x.poke(b'\x00' * size)
+            x.poke(b"\x00" * size)
             try:
                 yield x
             finally:
@@ -417,18 +469,15 @@ class CoreClient:
     def shell(self):
         self._logger.disabled = True
 
-        args = ['--rc']
-        home_rc = Path('~/.xonshrc').expanduser()
-        if home_rc.exists():
-            args.append(str(home_rc.expanduser().absolute()))
-        args.append(str((Path(__file__).parent / 'xonshrc.py').absolute()))
+        args = ["--rc"]
+        args.append(str((Path(__file__).parent / "xonshrc.py").absolute()))
 
-        XSH.ctx['_client_to_reuse'] = self
+        XSH.ctx["_client_to_reuse"] = self
 
         try:
-            logging.getLogger('parso.python.diff').disabled = True
-            logging.getLogger('parso.cache').disabled = True
-            logging.getLogger('asyncio').disabled = True
+            logging.getLogger("parso.python.diff").disabled = True
+            logging.getLogger("parso.cache").disabled = True
+            logging.getLogger("asyncio").disabled = True
             xonsh_main(args)
         except SystemExit:
             self._logger.disabled = False
@@ -436,8 +485,8 @@ class CoreClient:
     def _execute(self, argv: list[str], envp: list[str], background=False) -> int:
         try:
             return self.rpc_call(MsgId.REQ_EXEC, background=background, argv=argv, envp=envp).pid
-        except ServerResponseError:
-            raise SpawnError(f'failed to spawn: {argv}')
+        except ServerResponseError as e:
+            raise SpawnError(f"failed to spawn: {argv}") from e
 
     def enter_pty_mode(self, stdin=sys.stdin, stdout=sys.stdout):
         # the socket must be non-blocking for using select()
@@ -446,7 +495,7 @@ class CoreClient:
         exit_code = None
         try:
             fds = []
-            if hasattr(stdin, 'fileno'):
+            if hasattr(stdin, "fileno"):
                 fds.append(stdin)
             else:
                 data = stdin
@@ -472,15 +521,15 @@ class CoreClient:
                         try:
                             response = self._bridge.sock.rpc_msg_recv_pty()
                         except ConnectionResetError:
-                            print('Bye. 👋')
+                            print("Bye. 👋")
                             running = False
                             break
-                        msg_type = response.WhichOneof('type')
-                        if msg_type == 'buffer':
+                        msg_type = response.WhichOneof("type")
+                        if msg_type == "buffer":
                             stdout.write(response.buffer.decode())
-                            if hasattr(stdout, 'flush'):
+                            if hasattr(stdout, "flush"):
                                 stdout.flush()
-                        elif msg_type == 'exit_code':
+                        elif msg_type == "exit_code":
                             exit_code = response.exit_code
                             running = False
                             break
@@ -501,7 +550,7 @@ class CoreClient:
         tty.setraw(fd)
 
     def raise_errno_exception(self, message: str):
-        message += f' ({self.last_error})'
+        message += f" ({self.last_error})"
         exceptions = {
             EPERM: RpcPermissionError,
             ENOENT: RpcFileNotFoundError,
@@ -531,4 +580,4 @@ class CoreClient:
         return CaptureFD(self, fd, sock_buf_size)
 
     def __repr__(self):
-        return f'<{self.__class__.__name__}: {self.pid} | {self.progname}>'
+        return f"<{self.__class__.__name__}: {self.pid} | {self.progname}>"
