@@ -47,15 +47,16 @@ def _default_json_encoder(obj):
 def _pretty_json(buf, colored=True, default=_default_json_encoder):
     formatted_json = json.dumps(buf, sort_keys=True, indent=4, default=default)
     if colored:
-        colorful_json = highlight(formatted_json, lexers.JsonLexer(),
-                                  formatters.TerminalTrueColorFormatter(style='stata-dark'))
+        colorful_json = highlight(
+            formatted_json, lexers.JsonLexer(), formatters.TerminalTrueColorFormatter(style="stata-dark")
+        )
         return colorful_json
     else:
         return formatted_json
 
 
 def element_completer(xsh, action, completer, alias, command):
-    client = XSH.env['rpc']
+    client = XSH.env["rpc"]
     result = []
     if not client.accessibility.enabled:
         return result
@@ -67,21 +68,18 @@ def element_completer(xsh, action, completer, alias, command):
 
 
 def path_completer(xsh, action, completer, alias, command):
-    client = XSH.env['rpc']
+    client = XSH.env["rpc"]
     pwd = client.fs.pwd()
-    is_absolute = command.prefix.startswith('/')
+    is_absolute = command.prefix.startswith("/")
     dirpath = Path(pwd) / command.prefix
     if not client.fs.accessible(dirpath):
         dirpath = dirpath.parent
     result = []
     for f in client.fs.scandir(dirpath):
-        if is_absolute:
-            completion_option = str(dirpath / f.name)
-        else:
-            completion_option = str((dirpath / f.name).relative_to(pwd))
+        completion_option = str(dirpath / f.name) if is_absolute else str((dirpath / f.name).relative_to(pwd))
         try:
             if f.is_dir():
-                result.append(f'{completion_option}/')
+                result.append(f"{completion_option}/")
             else:
                 result.append(completion_option)
         except RpcClientException:
@@ -91,21 +89,18 @@ def path_completer(xsh, action, completer, alias, command):
 
 
 def dir_completer(xsh, action, completer, alias, command):
-    client = XSH.env['rpc']
+    client = XSH.env["rpc"]
     pwd = client.fs.pwd()
-    is_absolute = command.prefix.startswith('/')
+    is_absolute = command.prefix.startswith("/")
     dirpath = Path(pwd) / command.prefix
     if not client.fs.accessible(dirpath):
         dirpath = dirpath.parent
     result = []
     for f in client.fs.scandir(dirpath):
-        if is_absolute:
-            completion_option = str(dirpath / f.name)
-        else:
-            completion_option = str((dirpath / f.name).relative_to(pwd))
+        completion_option = str(dirpath / f.name) if is_absolute else str((dirpath / f.name).relative_to(pwd))
         try:
             if f.is_dir():
-                result.append(f'{completion_option}/')
+                result.append(f"{completion_option}/")
         except RpcClientException:
             result.append(completion_option)
 
@@ -168,12 +163,12 @@ class RpcLsStub(LsStub):
     def now(self):
         return self._client.time.now()
 
-    def listdir(self, path='.'):
+    def listdir(self, path="."):
         self._paths_entries[path] = self._client.fs.scandir(path)
         return [e.name for e in self._paths_entries[path]]
 
     def system(self):
-        return 'Darwin'
+        return "Darwin"
 
     def getenv(self, key, default=None):
         return self._client.getenv(key)
@@ -181,21 +176,21 @@ class RpcLsStub(LsStub):
     def get_tty_width(self):
         return os.get_terminal_size().columns
 
-    def print(self, *objects, sep=' ', end='\n', file=sys.stdout, flush=False):
+    def print(self, *objects, sep=" ", end="\n", file=sys.stdout, flush=False):
         print(objects[0], end=end, file=self._stdout, flush=flush)
 
 
 class XonshRc:
     def __init__(self):
-        self.client: ClientType = XSH.ctx.get('_client_to_reuse')
+        self.client: ClientType = XSH.ctx.get("_client_to_reuse")
         self._commands = {}
         self._orig_aliases = {}
-        self._orig_prompt = XSH.env['PROMPT']
-        self._register_rpc_command('rpc-connect', lambda: self._rpc_connect(self.client))
-        self._register_rpc_command('rpc-list-commands', self._rpc_list_commands)
+        self._orig_prompt = XSH.env["PROMPT"]
+        self._register_rpc_command("rpc-connect", lambda: self._rpc_connect(self.client))
+        self._register_rpc_command("rpc-list-commands", self._rpc_list_commands)
         self._rpc_connect(self.client)
 
-        print_color('''
+        print_color("""
         {BOLD_WHITE}Welcome to xonsh-rpc shell! 👋{RESET}
         Use {CYAN}$rpc{RESET} to access current client.
         Use {CYAN}rpc-list-commands{RESET} to view a list of all available special commands.
@@ -206,7 +201,7 @@ class XonshRc:
         * Power: ControlEnd
         * VolUp: ControlShiftUp
         * VolDown: ControlShiftDown
-        ''')
+        """)
 
     def _register_arg_parse_alias(self, name: str, handler: Union[Callable, str]):
         handler = ArgParserAlias(func=handler, has_args=True, prog=name)
@@ -233,80 +228,82 @@ class XonshRc:
         self.client = client_to_reuse
 
         # clear all host commands except for some useful ones
-        XSH.env['PATH'].clear()
-        for cmd in ['wc', 'grep', 'egrep', 'sed', 'awk', 'print', 'yes', 'cat', 'file']:
+        XSH.env["PATH"].clear()
+        XSH.env.pop("XONSH_COLOR_STYLE")
+        for cmd in ["wc", "grep", "egrep", "sed", "awk", "print", "yes", "cat", "file"]:
             executable = shutil.which(cmd)
             if executable is not None:
                 self._register_rpc_command(cmd.strip(), executable)
 
         # -- rpc
-        self._register_arg_parse_alias('rpc-disconnect', self._rpc_disconnect)
-        self._register_arg_parse_alias('rpc-which', self._rpc_which)
+        self._register_arg_parse_alias("rpc-disconnect", self._rpc_disconnect)
+        self._register_arg_parse_alias("rpc-which", self._rpc_which)
 
         # -- automation
-        self._register_arg_parse_alias('list-elements', self._rpc_list_elements)
-        self._register_arg_parse_alias('press-elements', self._rpc_press_elements)
-        self._register_arg_parse_alias('enable-accessibility', self._rpc_enable_accessibility)
-        self._register_arg_parse_alias('disable-accessibility', self._rpc_disable_accessibility)
-        self._register_arg_parse_alias('press-keys', self._rpc_press_keys)
-        self._register_arg_parse_alias('swipe-up', self._rpc_swipe_up)
-        self._register_arg_parse_alias('swipe-down', self._rpc_swipe_down)
-        self._register_arg_parse_alias('swipe-left', self._rpc_swipe_left)
-        self._register_arg_parse_alias('swipe-right', self._rpc_swipe_right)
+        self._register_arg_parse_alias("list-elements", self._rpc_list_elements)
+        self._register_arg_parse_alias("press-elements", self._rpc_press_elements)
+        self._register_arg_parse_alias("enable-accessibility", self._rpc_enable_accessibility)
+        self._register_arg_parse_alias("disable-accessibility", self._rpc_disable_accessibility)
+        self._register_arg_parse_alias("press-keys", self._rpc_press_keys)
+        self._register_arg_parse_alias("swipe-up", self._rpc_swipe_up)
+        self._register_arg_parse_alias("swipe-down", self._rpc_swipe_down)
+        self._register_arg_parse_alias("swipe-left", self._rpc_swipe_left)
+        self._register_arg_parse_alias("swipe-right", self._rpc_swipe_right)
 
         # -- processes
-        self._register_rpc_command('run', self._rpc_run)
-        self._register_rpc_command('run-async', self._rpc_run_async)
-        if self.client.fs.accessible('/bin/ps'):
-            XSH.aliases['ps'] = 'run ps'
+        self._register_rpc_command("run", self._rpc_run)
+        self._register_rpc_command("run-async", self._rpc_run_async)
+        if self.client.fs.accessible("/bin/ps"):
+            XSH.aliases["ps"] = "run ps"
         else:
-            self._register_arg_parse_alias('ps', self._rpc_ps)
-        self._register_arg_parse_alias('kill', self._rpc_kill)
-        self._register_arg_parse_alias('killall', self._rpc_killall)
+            self._register_arg_parse_alias("ps", self._rpc_ps)
+        self._register_arg_parse_alias("kill", self._rpc_kill)
+        self._register_arg_parse_alias("killall", self._rpc_killall)
 
         # -- fs
-        self._register_rpc_command('ls', self._rpc_ls)
-        self._register_arg_parse_alias('ln', self._rpc_ln)
-        self._register_arg_parse_alias('touch', self._rpc_touch)
-        self._register_arg_parse_alias('pwd', self._rpc_pwd)
-        self._register_arg_parse_alias('cd', self._rpc_cd)
-        self._register_arg_parse_alias('rm', self._rpc_rm)
-        self._register_arg_parse_alias('mv', self._rpc_mv)
-        self._register_arg_parse_alias('cp', self._rpc_cp)
-        self._register_arg_parse_alias('mkdir', self._rpc_mkdir)
-        self._register_arg_parse_alias('cat', self._rpc_cat)
-        self._register_arg_parse_alias('bat', self._rpc_bat)
-        self._register_arg_parse_alias('pull', self._rpc_pull)
-        self._register_arg_parse_alias('push', self._rpc_push)
-        self._register_arg_parse_alias('chmod', self._rpc_chmod)
-        self._register_arg_parse_alias('chown', self._rpc_chown)
-        self._register_arg_parse_alias('find', self._rpc_find)
-        self._register_arg_parse_alias('xattr-get-dict', self._rpc_xattr_get_dict)
-        self._register_arg_parse_alias('vim', self._rpc_vim)
-        self._register_arg_parse_alias('entitlements', self._rpc_entitlements)
+        self._register_rpc_command("ls", self._rpc_ls)
+        self._register_arg_parse_alias("ln", self._rpc_ln)
+        self._register_arg_parse_alias("touch", self._rpc_touch)
+        self._register_arg_parse_alias("pwd", self._rpc_pwd)
+        self._register_arg_parse_alias("cd", self._rpc_cd)
+        self._register_arg_parse_alias("rm", self._rpc_rm)
+        self._register_arg_parse_alias("mv", self._rpc_mv)
+        self._register_arg_parse_alias("cp", self._rpc_cp)
+        self._register_arg_parse_alias("mkdir", self._rpc_mkdir)
+        self._register_arg_parse_alias("cat", self._rpc_cat)
+        self._register_arg_parse_alias("bat", self._rpc_bat)
+        self._register_arg_parse_alias("pull", self._rpc_pull)
+        self._register_arg_parse_alias("push", self._rpc_push)
+        self._register_arg_parse_alias("chmod", self._rpc_chmod)
+        self._register_arg_parse_alias("chown", self._rpc_chown)
+        self._register_arg_parse_alias("find", self._rpc_find)
+        self._register_arg_parse_alias("xattr-get-dict", self._rpc_xattr_get_dict)
+        self._register_arg_parse_alias("vim", self._rpc_vim)
+        self._register_arg_parse_alias("entitlements", self._rpc_entitlements)
 
         # -- plist
-        self._register_arg_parse_alias('plshow', self._rpc_plshow)
+        self._register_arg_parse_alias("plshow", self._rpc_plshow)
 
         # -- media
-        self._register_arg_parse_alias('record', self._rpc_record)
-        self._register_arg_parse_alias('play', self._rpc_play)
+        self._register_arg_parse_alias("record", self._rpc_record)
+        self._register_arg_parse_alias("play", self._rpc_play)
 
         # -- misc
-        self._register_arg_parse_alias('open', self._rpc_open)
-        self._register_arg_parse_alias('date', self._rpc_date)
-        self._register_arg_parse_alias('env', self._rpc_env)
-        self._register_arg_parse_alias('rpc-file', self._rpc_file)
+        self._register_arg_parse_alias("open", self._rpc_open)
+        self._register_arg_parse_alias("date", self._rpc_date)
+        self._register_arg_parse_alias("env", self._rpc_env)
+        self._register_arg_parse_alias("rpc-file", self._rpc_file)
 
-        XSH.env['PROMPT'] = f'[{{BOLD_GREEN}}{self.client.uname.nodename}{{RESET}} ' \
-                            f'{{BOLD_YELLOW}}{{rpc_cwd}}{{RESET}}]{{prompt_end}} '
-        XSH.env['PROMPT_FIELDS']['rpc_cwd'] = self._rpc_cwd
-        XSH.env['PROMPT_FIELDS']['prompt_end'] = self._prompt
+        XSH.env["PROMPT"] = (
+            f"[{{BOLD_GREEN}}{self.client.uname.nodename}{{RESET}} {{BOLD_YELLOW}}{{rpc_cwd}}{{RESET}}]{{prompt_end}} "
+        )
+        XSH.env["PROMPT_FIELDS"]["rpc_cwd"] = self._rpc_cwd
+        XSH.env["PROMPT_FIELDS"]["prompt_end"] = self._prompt
 
     def _prompt(self) -> str:
         if len(XSH.history) == 0 or XSH.history[-1].rtn == 0:
-            return '{BOLD_GREEN}${RESET}'
-        return '{BOLD_RED}${RESET}'
+            return "{BOLD_GREEN}${RESET}"
+        return "{BOLD_RED}${RESET}"
 
     def _rpc_cwd(self) -> str:
         return self.client.fs.pwd()
@@ -336,13 +333,15 @@ class XonshRc:
         list all labels in current main application')
         """
         for element in self.client.accessibility.primary_app:
-            print_color(f'🏷  '
-                        f'{{BOLD_WHITE}}Label:{{RESET}} {element.label} '
-                        f'{{BOLD_WHITE}}Value:{{RESET}} {element.value} '
-                        f'{{RESET}}',
-                        file=sys.stdout)
+            print_color(
+                f"🏷  "
+                f"{{BOLD_WHITE}}Label:{{RESET}} {element.label} "
+                f"{{BOLD_WHITE}}Value:{{RESET}} {element.value} "
+                f"{{RESET}}",
+                file=sys.stdout,
+            )
 
-    def _rpc_press_elements(self, label: Annotated[list[str], Arg(nargs='+', completer=element_completer)]):
+    def _rpc_press_elements(self, label: Annotated[list[str], Arg(nargs="+", completer=element_completer)]):
         """
         press labels list by given order
         """
@@ -360,19 +359,25 @@ class XonshRc:
         """
         self.client.accessibility.enabled = False
 
-    def _rpc_press_keys(self, key: Annotated[
-        list[str], Arg(nargs='+',
-                       completer=lambda xsh, action, completer, alias, command: ['power', 'home', 'volup', 'voldown',
-                                                                                 'mute'])]):
+    def _rpc_press_keys(
+        self,
+        key: Annotated[
+            list[str],
+            Arg(
+                nargs="+",
+                completer=lambda xsh, action, completer, alias, command: ["power", "home", "volup", "voldown", "mute"],
+            ),
+        ],
+    ):
         """
         press key list by given order
         """
         keys_map = {
-            'power': self.client.hid.send_power_button_press,
-            'home': self.client.hid.send_home_button_press,
-            'volup': self.client.hid.send_volume_up_button_press,
-            'voldown': self.client.hid.send_volume_down_button_press,
-            'mute': self.client.hid.send_mute_button_press,
+            "power": self.client.hid.send_power_button_press,
+            "home": self.client.hid.send_home_button_press,
+            "volup": self.client.hid.send_volume_up_button_press,
+            "voldown": self.client.hid.send_volume_down_button_press,
+            "mute": self.client.hid.send_mute_button_press,
         }
         for k in key:
             keys_map[k]()
@@ -402,8 +407,8 @@ class XonshRc:
         self.client.hid.send_swipe_right()
 
     def _rpc_run(self, args, stdin, stdout, stderr):
-        parser = ArgumentParser(prog='run', description='execute a program')
-        parser.add_argument('arg', nargs='+')
+        parser = ArgumentParser(prog="run", description="execute a program")
+        parser.add_argument("arg", nargs="+")
         args = parser.parse_args(args)
         if not stdin:
             stdin = sys.stdin
@@ -411,12 +416,12 @@ class XonshRc:
         return result.error
 
     def _rpc_run_async(self, args, stdin, stdout, stderr):
-        parser = ArgumentParser(prog='run-async', description='execute a program in background')
-        parser.add_argument('arg', nargs='+')
+        parser = ArgumentParser(prog="run-async", description="execute a program in background")
+        parser.add_argument("arg", nargs="+")
         args = parser.parse_args(args)
         print(self.client.spawn(args.arg, raw_tty=False, background=True), file=stdout, flush=True)
 
-    def _rpc_kill(self, pid: int, signal_number: Annotated[int, Arg(nargs='?', default=SIGTERM)]):
+    def _rpc_kill(self, pid: int, signal_number: Annotated[int, Arg(nargs="?", default=SIGTERM)]):
         """
         kill a process
         """
@@ -424,7 +429,7 @@ class XonshRc:
         pid = int(pid)
         self.client.processes.kill(pid, signal_number)
 
-    def _rpc_killall(self, expression: str, signal_number: Annotated[int, Arg(nargs='?', default=SIGTERM)]):
+    def _rpc_killall(self, expression: str, signal_number: Annotated[int, Arg(nargs="?", default=SIGTERM)]):
         """
         killall processes with given basename given as a "contain" expression
         """
@@ -433,22 +438,26 @@ class XonshRc:
             p.kill(signal_number)
 
     def _rpc_ps(self):
-        """ list processes """
+        """list processes"""
         for p in self.client.processes.list():
-            print_color(f'{p.pid:5} {p.path}', file=sys.stdout, flush=True)
+            print_color(f"{p.pid:5} {p.path}", file=sys.stdout, flush=True)
 
     def _rpc_ls(self, args, stdin, stdout, stderr):
-        """ list files """
+        """list files"""
         try:
-            with ls_cli.make_context('ls', args) as ctx:
-                files = list(map(self._relative_path, ctx.params.pop('files')))
+            with ls_cli.make_context("ls", args) as ctx:
+                files = list(map(self._relative_path, ctx.params.pop("files")))
                 files = files if files else [self._rpc_pwd()]
                 Ls(RpcLsStub(self.client, stdout))(*files, **ctx.params)
         except Exit:
             pass
 
-    def _rpc_ln(self, src: Annotated[str, Arg(completer=path_completer)],
-                dst: Annotated[str, Arg(completer=path_completer)], symlink=False):
+    def _rpc_ln(
+        self,
+        src: Annotated[str, Arg(completer=path_completer)],
+        dst: Annotated[str, Arg(completer=path_completer)],
+        symlink=False,
+    ):
         """
         create a link
 
@@ -466,7 +475,7 @@ class XonshRc:
         """
         create an empty file
         """
-        self.client.fs.write_file(filename, b'')
+        self.client.fs.write_file(filename, b"")
 
     def _rpc_pwd(self):
         """
@@ -480,8 +489,9 @@ class XonshRc:
         """
         self.client.fs.chdir(path)
 
-    def _rpc_rm(self, path: Annotated[list[str], Arg(nargs='+', completer=path_completer)], recursive=False,
-                force=False):
+    def _rpc_rm(
+        self, path: Annotated[list[str], Arg(nargs="+", completer=path_completer)], recursive=False, force=False
+    ):
         """
         remove files
 
@@ -495,22 +505,28 @@ class XonshRc:
         for p in path:
             self.client.fs.remove(p, recursive=recursive, force=force)
 
-    def _rpc_mv(self, src: Annotated[str, Arg(completer=path_completer)],
-                dst: Annotated[str, Arg(completer=path_completer)]):
+    def _rpc_mv(
+        self, src: Annotated[str, Arg(completer=path_completer)], dst: Annotated[str, Arg(completer=path_completer)]
+    ):
         """
         move a file
         """
         self.client.fs.rename(src, dst)
 
-    def _rpc_cp(self, src: Annotated[str, Arg(completer=path_completer)],
-                dst: Annotated[str, Arg(completer=path_completer)]):
+    def _rpc_cp(
+        self, src: Annotated[str, Arg(completer=path_completer)], dst: Annotated[str, Arg(completer=path_completer)]
+    ):
         """
         copy a file
         """
         self.client.fs.write_file(dst, self.client.fs.read_file(src))
 
-    def _rpc_mkdir(self, filename: Annotated[str, Arg(completer=path_completer)], parents: bool = False,
-                   mode: Annotated[str, Arg(nargs='?')] = '777'):
+    def _rpc_mkdir(
+        self,
+        filename: Annotated[str, Arg(completer=path_completer)],
+        parents: bool = False,
+        mode: Annotated[str, Arg(nargs="?")] = "777",
+    ):
         """
         create a directory
 
@@ -521,15 +537,15 @@ class XonshRc:
         """
         self.client.fs.mkdir(filename, mode=int(mode, 8), parents=parents)
 
-    def _rpc_cat(self, filename: Annotated[list[str], Arg(nargs='+', completer=path_completer)]):
+    def _rpc_cat(self, filename: Annotated[list[str], Arg(nargs="+", completer=path_completer)]):
         """
         read a list of files
         """
-        buf = b''
+        buf = b""
         for current in filename:
-            with self.client.fs.open(current, 'r') as f:
+            with self.client.fs.open(current, "r") as f:
                 buf += f.read()
-        buf += b'\n'
+        buf += b"\n"
         try:
             return buf.decode()
         except UnicodeDecodeError:
@@ -543,9 +559,11 @@ class XonshRc:
             os.system(f'bat "{f}"')
 
     def _rpc_pull(
-            self, files: Annotated[list[str],
-                                   Arg(nargs='+', completer=path_completer)],
-            recursive: bool = False, force: bool = False):
+        self,
+        files: Annotated[list[str], Arg(nargs="+", completer=path_completer)],
+        recursive: bool = False,
+        force: bool = False,
+    ):
         """
         pull files from remote
 
@@ -562,9 +580,11 @@ class XonshRc:
         return self._pull(files, local, recursive, force)
 
     def _rpc_push(
-            self, files: Annotated[list[str],
-                                   Arg(nargs='+', completer=path_completer)],
-            recursive: bool = False, force: bool = False):
+        self,
+        files: Annotated[list[str], Arg(nargs="+", completer=path_completer)],
+        recursive: bool = False,
+        force: bool = False,
+    ):
         """
         push files to remote
 
@@ -605,7 +625,7 @@ class XonshRc:
         self.client.fs.chown(filename, uid, gid, recursive=recursive)
 
     def _rpc_find(self, filename: Annotated[str, Arg(completer=path_completer)], depth=True):
-        """ find file recursively """
+        """find file recursively"""
         for f in self.client.fs.find(filename, topdown=not depth):
             print_color(f, file=sys.stdout, flush=True)
 
@@ -613,7 +633,7 @@ class XonshRc:
         """
         parse and show plist
         """
-        with self.client.fs.open(filename, 'r') as f:
+        with self.client.fs.open(filename, "r") as f:
             return _pretty_json(plistlib.loads(f.read()))
 
     def _rpc_record(self, filename: Annotated[str, Arg(completer=path_completer)], duration: int):
@@ -626,8 +646,9 @@ class XonshRc:
             time.sleep(duration)
             r.stop()
 
-    def _rpc_play(self, filename: Annotated[str, Arg(completer=path_completer)],
-                  duration: Annotated[int, Arg(nargs='?')] = None):
+    def _rpc_play(
+        self, filename: Annotated[str, Arg(completer=path_completer)], duration: Annotated[int, Arg(nargs="?")] = None
+    ):
         """
         play file
         """
@@ -638,21 +659,21 @@ class XonshRc:
                 time.sleep(duration)
             else:
                 while r.playing:
-                    time.sleep(.1)
+                    time.sleep(0.1)
 
     def _rpc_open(self, filename: Annotated[str, Arg(completer=path_completer)]):
         """
         open a file from remote using default program')
         """
-        open_ = plumbum.local['open']
-        upload_changes = 'Upload changes'
-        discard_changes = 'Discard changes'
+        open_ = plumbum.local["open"]
+        upload_changes = "Upload changes"
+        discard_changes = "Discard changes"
         with self._edit_remotely(filename) as f:
             open_(f)
             if prompt_for_choice([upload_changes, discard_changes]) == upload_changes:
                 self._push(f, filename)
 
-    def _rpc_date(self, new_date: Annotated[str, Arg(nargs='?')] = None):
+    def _rpc_date(self, new_date: Annotated[str, Arg(nargs="?")] = None):
         """
         get/set date
         """
@@ -661,8 +682,8 @@ class XonshRc:
         self.client.time.set_current(datetime.fromisoformat(new_date))
 
     def _rpc_which(self, filename: str):
-        """ traverse $PATH to find the first matching executable """
-        for p in self.client.getenv('PATH').split(':'):
+        """traverse $PATH to find the first matching executable"""
+        for p in self.client.getenv("PATH").split(":"):
             abs_filename = (Path(p) / filename).absolute()
             if self.client.fs.accessible((Path(p) / filename).absolute()):
                 return abs_filename
@@ -671,13 +692,13 @@ class XonshRc:
         """
         view all environment variables
         """
-        return '\n'.join(self.client.environ)
+        return "\n".join(self.client.environ)
 
     def _rpc_file(self, filename: str):
         """
         show file type
         """
-        file = plumbum.local['file']
+        file = plumbum.local["file"]
         with self._remote_file(filename) as f:
             return file(f)
 
@@ -685,9 +706,9 @@ class XonshRc:
         """
         list all rpc commands
         """
-        buf = ''
-        for k, v in self._commands.items():
-            buf += f'👾 {k}\n'
+        buf = ""
+        for k, _v in self._commands.items():
+            buf += f"👾 {k}\n"
         print(buf)
 
     @contextlib.contextmanager
@@ -720,30 +741,30 @@ class XonshRc:
 
 
 # actual RC contents
-XSH.aliases['xontrib']('load z argcomplete coreutils fzf-widgets jedi'.split())
-XSH.env['fzf_history_binding'] = ""  # Ctrl+R
-XSH.env['fzf_ssh_binding'] = ""  # Ctrl+S
-XSH.env['fzf_file_binding'] = ""  # Ctrl+T
-XSH.env['fzf_dir_binding'] = ""  # Ctrl+G
+XSH.aliases["xontrib"](["load", "z", "argcomplete", "coreutils", "fzf-widgets", "jedi"])
+XSH.env["fzf_history_binding"] = ""  # Ctrl+R
+XSH.env["fzf_ssh_binding"] = ""  # Ctrl+S
+XSH.env["fzf_file_binding"] = ""  # Ctrl+T
+XSH.env["fzf_dir_binding"] = ""  # Ctrl+G
 
 rc = XonshRc()
-XSH.env['rpc'] = rc.client
+XSH.env["rpc"] = rc.client
 
 
 @events.on_ptk_create
 def custom_keybindings(bindings, **kw):
     @bindings.add(Keys.ControlHome)
     def press_home(event):
-        XSH.env['rpc'].hid.send_home_button_press()
+        XSH.env["rpc"].hid.send_home_button_press()
 
     @bindings.add(Keys.ControlEnd)
     def press_power(event):
-        XSH.env['rpc'].hid.send_power_button_press()
+        XSH.env["rpc"].hid.send_power_button_press()
 
     @bindings.add(Keys.ControlShiftUp)
     def press_volume_up(event):
-        XSH.env['rpc'].hid.send_volume_down_button_press()
+        XSH.env["rpc"].hid.send_volume_down_button_press()
 
     @bindings.add(Keys.ControlShiftDown)
     def press_volume_down(event):
-        XSH.env['rpc'].hid.send_volume_up_button_press()
+        XSH.env["rpc"].hid.send_volume_up_button_press()
