@@ -1,3 +1,5 @@
+import contextlib
+
 import pytest
 
 from rpcclient.exceptions import RpcPermissionError
@@ -6,14 +8,10 @@ pytestmark = pytest.mark.darwin
 
 
 def test_query_certificates(client):
-    try:
+    with contextlib.suppress(RpcPermissionError):
         assert len(client.keychain.query_certificates()) > 1
-    except RpcPermissionError:
-        pass
 
 
 def test_query_keys(client):
-    try:
+    with contextlib.suppress(RpcPermissionError):
         assert len(client.keychain.query_keys()) > 1
-    except RpcPermissionError:
-        pass
