@@ -2,11 +2,11 @@ def test_valid_gethostbyname(client):
     """
     :param rpcclient.client.Client client:
     """
-    assert client.network.gethostbyname('google.com') is not None
+    assert client.network.gethostbyname("google.com") is not None
 
 
 def test_invalid_gethostbyname(client):
     """
     :param rpcclient.client.Client client:
     """
-    assert client.network.gethostbyname('google.com1') is None
+    assert client.network.gethostbyname("google.com1") is None
